export function durationFormat(duration, sep = null) {
    duration = parseInt(duration);
    if (isNaN(duration)) {
        return '';
    }
    var hour = parseInt(duration / 3600);
    var r = duration % 3600;
    var min = parseInt(r / 60);
    var sec = parseInt(r % 60);
    hour = isNaN(hour) ? 0 : hour;
    min = isNaN(min) ? 0 : min;
    sec = isNaN(sec) ? 0 : sec;
    if (sep) {
        hour = hour > 9 ? hour : '0' + hour
        min = min > 9 ? min : '0' + min
        sec = sec > 9 ? sec : '0' + sec
        return hour + sep + min + sep + sec;
    } else {
        let s = '';
        if (hour > 0) {
            s += hour + "h"
        }
        if (min > 0 || s != '') {
            s += min + "m"
        }
        s += sec + "s";
        return s;
    }
}

export function monryFormat(number, decimals = 2, decPoint = '.', thousandsSep = ',') {
    number = (number + '').replace(/[^0-9+-Ee.]/g, '')
    let n = !isFinite(+number) ? 0 : +number
    let prec = !isFinite(+decimals) ? 0 : Math.abs(decimals)
    let sep = (typeof thousandsSep === 'undefined') ? ',' : thousandsSep
    let dec = (typeof decPoint === 'undefined') ? '.' : decPoint
    let s = ''
    let toFixedFix = function (n, prec) {
        let k = Math.pow(10, prec)
        return '' + Math.ceil(n * k) / k
    }
    s = (prec ? toFixedFix(n, prec) : '' + Math.round(n)).split('.')
    let re = /(-?\d+)(\d{3})/
    while (re.test(s[0])) {
        s[0] = s[0].replace(re, '$1' + sep + '$2')
    }
    if ((s[1] || '').length < prec) {
        s[1] = s[1] || ''
        s[1] += new Array(prec - s[1].length + 1).join('0')
    }
    return s.join(dec)
}

export function byteFormat(bytes) {
    if (bytes === 0) return '0 B';
    var k = 1024;
    let sizes = ['B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB'];
    let i = Math.floor(Math.log(bytes) / Math.log(k)) //return (bytes / Math.pow(k, i)) + ' ' + sizes[i];

    return (bytes / Math.pow(k, i)).toPrecision(3) + ' ' + sizes[i];
}