import { defineStore } from 'pinia'
import { getBaseUrl } from '@/apis/request'

const useUserStore = defineStore('user', {
    state: () => {
        return {
            uid: '',
            username: '',
            email: '',
            avatar: '//rd.echo.me/fake/users/user-1.jpg',
            pwdhash: '',
            accessToken: '*',
            tokenExpiredAt: 0,
            permissions: [],
            description: '',
            loginDevice: false,
            hiddlePhone: false, //号码是否隐藏
            deviceRegistered: false,
            unreadMsgCount: 0,
        }
    },
    getters: {},
    actions: {
        setUserID(uid) {
            this.uid = uid
        },
        setAccessToken(token, ttl) {
            this.accessToken = token
            if (ttl <= 0) {
                this.tokenExpiredAt = 0;
                sessionStorage.removeItem('G_PSID1');
            } else {
                this.tokenExpiredAt = ((new Date()).getTime() / 1000) + ttl;
                sessionStorage.setItem('G_PSID1', this.accessToken);
            }
        },
        setUsername(s) {
            this.username = s
        },

        setEmail(s) {
            this.email = s
        },
        setPassword(s) {
            this.pwdhash = btoa(s)
        },
        setAvatar(s) {
            if (s.indexOf('//') === -1) {
                s = getBaseUrl() + s;
            }
            this.avatar = s
        },
        setAutoLoginDevice(s) {
            this.loginDevice = s;
        },
        setDeviceRegisterState(ok) {
            this.deviceRegistered = ok
        },
        setPermissions(s) {
            if (typeof s === 'string') {
                try {
                    this.permissions = JSON.parse(s)
                } catch (e) { }
            } else {
                this.permissions = s
            }
        },
        isAuthorization() {
            let timestamp = (new Date()).getTime() / 1000;
            return this.tokenExpiredAt > timestamp;
        },
        incUnreadMsgCount() {
            this.unreadMsgCount++
        },
        decUnreadMsgCount() {
            this.unreadMsgCount--
        },
        setUnreadMsgCount(n) {
            this.unreadMsgCount = n
        },
        getUserID() {
            return this.uid;
        },
        getAccessToken() {
            return this.accessToken;
        },
        getAutoLoginDevice() { 
            return this.loginDevice
        },
        getPassword() {
            return atob(this.pwdhash);
        },
        getUnreadMsgCount() {
            return this.unreadMsgCount
        },
        getDeviceRegistered() {
            return this.deviceRegistered;
        },
        hasPermission(permission) {
            let ret = false
            if (typeof permission === 'boolean') {
                ret = permission
            } else if (Array.isArray(permission)) {
                for (let s of permission) {
                    if (this.permissions.indexOf(s) > -1) {
                        ret = true
                        break
                    }
                }
            } else {
                ret = this.permissions.indexOf(permission) > -1
            }
            return ret
        },
    },
    persist: {
        key: 'G_PTST3',
        paths: ['accessToken', 'tokenExpiredAt', 'pwdhash', 'loginDevice'],
        storage: sessionStorage,
    },
})

export default useUserStore